mix fix_json (slack_open_api v0.0.7)

Mix task to fix endpoints in the Slack OpenAPI specification.

Usage

mix fix_json

This will modify endpoints that are incorrectly specified as GET but should be POST. Any GET endpoint that has "application/json" in its response content types will be converted to POST with form data parameters.

Summary

Functions

fix_endpoints(spec)